#!/usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { program as commander } from 'commander';
import { createRequire } from 'module';
const require = createRequire(import.meta.url);
import * as CratesUpdater from './CratesUpdater.js';
const { bin, description, version } = require('../package.json');
commander
    .name(Object.keys(bin)[0])
    .description(description)
    .arguments('<package>')
    .arguments('[packageVersion]')
    .option('-q, --quiet', 'quiet mode. Display newer version or nothing')
    .version(version, '-v, --version')
    .parse(process.argv);
if (!commander.args.length) {
    commander.outputHelp();
    process.exit(1);
}
const [packageName, packageVersion] = commander.args;
const commanderOptions = commander.opts();
void (() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (packageVersion) {
            const version = yield CratesUpdater.checkForUpdate(packageName, packageVersion);
            if (commanderOptions.quiet) {
                if (version) {
                    console.info(version);
                }
            }
            else {
                const text = version
                    ? `An update for ${packageName} is available: ${version}.`
                    : `No update for ${packageName} available.`;
                console.info(text);
            }
        }
        else {
            const version = yield CratesUpdater.getLatestVersion(packageName);
            const text = commanderOptions.quiet ? version.num : `Latest ${packageName} version is ${version.num}.`;
            console.info(text);
        }
        process.exit();
    }
    catch (error) {
        console.error(error.message);
        process.exit(1);
    }
}))();
